/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.manager.common.entity.resource;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

@JsonIgnoreProperties(ignoreUnknown = true)
public class InstanceResource extends CPUResource {
  private final int instances;

  public InstanceResource(int instances) {
    super(instances);
    this.instances = instances;
  }

  public InstanceResource() {
    super(Integer.MAX_VALUE);
    this.instances = Integer.MAX_VALUE;
  }

  public int getInstances() {
    return instances;
  }

  @Override
  public Resource toResource(int cores) {
    return new InstanceResource(cores);
  }

  @Override
  public String toJson() {
    return String.format("Instance: %d", this.instances);
  }

  @Override
  public String toString() {
    return this.toJson();
  }
}
